diff --git a/module/lang/lang-en.json b/module/lang/lang-en.json
index bb158c6f6099eb65a9507a04088704715477c5bc..29d2d9f92d85c94d9d0f1e4a057bb501cf571635 100644
--- a/module/lang/lang-en.json
+++ b/module/lang/lang-en.json
@@ -292,7 +292,7 @@
     "FORM_SNAPPING_TOLERANCE_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Snapping tolerance (in pixels)",
     "FORM_SNAPPING_TYPE_ACC_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Default snapping type",
     "FORM_SNAPPING_VISIBILITY_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Selected objects visibility",
-    "FORM_SNAPPING_AVOID_INTERSECTIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Avoid intersections",
+    "FORM_SNAPPING_AVOID_SUPERPOSITIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Avoid superposition",
     "FORM_SNAPPING_DEFAUT_LIMIT_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Manimum limit of points per object",
     "FORM_SNAPPING_DEFAUT_TOLERANCE_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Snapping tolerance (in pixels)",
     "FORM_SNAPPING_DEFAUT_TYPE_ACC_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Default snapping type",
diff --git a/module/lang/lang-fr.json b/module/lang/lang-fr.json
index 3e3bbb64968836dcbd18b1b31611a8708b5c803d..82fca25d0f2fa89bab33f3cd82e694948c3b78cc 100644
--- a/module/lang/lang-fr.json
+++ b/module/lang/lang-fr.json
@@ -292,7 +292,7 @@
     "FORM_SNAPPING_TOLERANCE_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Tolérance d'accrochage (pixels)",
     "FORM_SNAPPING_TYPE_ACC_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Type d'accrochage",
     "FORM_SNAPPING_VISIBILITY_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Visibilité des zones d'accrochage",
-    "FORM_SNAPPING_AVOID_INTERSECTIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Eviter les intersections",
+    "FORM_SNAPPING_AVOID_SUPERPOSITIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Eviter les superpositions",
     "FORM_SNAPPING_DEFAUT_LIMIT_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Limite de points accrochables",
     "FORM_SNAPPING_DEFAUT_TOLERANCE_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Tolérance d'accrochage (pixels)",
     "FORM_SNAPPING_DEFAUT_TYPE_ACC_CONFIGURATION_CONFIGURATION_VMAP_CONFIG": "Type d'accrochage",
diff --git a/module/template/tools/insert.html b/module/template/tools/insert.html
index a8937a7c680ceb14147b2c7fe1d108a1921340cd..b18ed5994bdc1bfbf72020ce20aae6262f22d3be 100644
--- a/module/template/tools/insert.html
+++ b/module/template/tools/insert.html
@@ -275,36 +275,33 @@
                     </div>
                 </div>
                 <div class="row">
-                    <div class="col-sm-6">
+                    <div class="col-sm-6" ng-show="aAvoidSuperpositionsBOs.length > 0">
                         <div class="row">
-                            <div class="col-sm-5">
-
-                            </div>
-                            <div class="col-sm-7">
-                                <h5 data-translate="FORM_SNAPPING_AVOID_INTERSECTIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG"></h5>
+                            <div class="col-sm-12 text-right">
+                                <h5 data-translate="FORM_SNAPPING_AVOID_SUPERPOSITIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG"></h5>
                             </div>
                         </div>
                         <div class="row"
-                                ng-repeat="bo in aAvoidIntersectionsBOs">
+                                ng-repeat="bo in aAvoidSuperpositionsBOs">
                             <div class="col-sm-5 text-right">
                                 <label>{{bo.bo_title}}</label>
                             </div>
                             <div class="col-sm-7 text-right">
                                 <div class="radio radio-inline">
                                     <input type="radio"
-                                            name="vmap_insert_snap_avoid_intersections_{{$index}}"
-                                            id="vmap_insert_snap_avoid_intersections_1_{{$index}}"
-                                            ng-model="ctrl.tmpSnapOptions.avoidIntersections[bo.bo_id]"
+                                            name="vmap_insert_snap_avoid_superpositions_{{$index}}"
+                                            id="vmap_insert_snap_avoid_superpositions_1_{{$index}}"
+                                            ng-model="ctrl.tmpSnapOptions.avoidSuperpositions[bo.bo_id]"
                                             ng-value="true">
-                                    <label for="vmap_insert_snap_avoid_intersections_1_{{$index}}">Oui</label>
+                                    <label for="vmap_insert_snap_avoid_superpositions_1_{{$index}}">Oui</label>
                                 </div>
                                 <div class="radio radio-inline">
                                     <input  type="radio"
-                                            name="vmap_insert_snap_avoid_intersections_{{$index}}"
-                                            id="vmap_insert_snap_avoid_intersections_2_{{$index}}"
-                                            ng-model="ctrl.tmpSnapOptions.avoidIntersections[bo.bo_id]"
+                                            name="vmap_insert_snap_avoid_superpositions_{{$index}}"
+                                            id="vmap_insert_snap_avoid_superpositions_2_{{$index}}"
+                                            ng-model="ctrl.tmpSnapOptions.avoidSuperpositions[bo.bo_id]"
                                             ng-value="false">
-                                    <label for="vmap_insert_snap_avoid_intersections_2_{{$index}}">Non</label>
+                                    <label for="vmap_insert_snap_avoid_superpositions_2_{{$index}}">Non</label>
                                 </div>
                             </div>
                         </div>
diff --git a/module/template/tools/select.html b/module/template/tools/select.html
index bb60aa4908a53e3fc0035c00f3d5a77a323a061b..24ae5ca8505ff719e24f57588e36d5e262265c44 100644
--- a/module/template/tools/select.html
+++ b/module/template/tools/select.html
@@ -323,36 +323,33 @@
                     </div>
                 </div>
                 <div class="row">
-                    <div class="col-sm-6">
+                    <div class="col-sm-6" ng-show="aAvoidSuperpositionsBOs.length > 0">
                         <div class="row">
-                            <div class="col-sm-5">
-
-                            </div>
-                            <div class="col-sm-7">
-                                <h5 data-translate="FORM_SNAPPING_AVOID_INTERSECTIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG"></h5>
+                            <div class="col-sm-12 text-right">
+                                <h5 data-translate="FORM_SNAPPING_AVOID_SUPERPOSITIONS_CONFIGURATION_CONFIGURATION_VMAP_CONFIG"></h5>
                             </div>
                         </div>
                         <div class="row"
-                                ng-repeat="bo in aAvoidIntersectionsBOs">
+                                ng-repeat="bo in aAvoidSuperpositionsBOs">
                             <div class="col-sm-5 text-right">
                                 <label>{{bo.bo_title}}</label>
                             </div>
                             <div class="col-sm-7 text-right">
                                 <div class="radio radio-inline">
                                     <input type="radio"
-                                            name="vmap_select_snap_avoid_intersections_{{$index}}"
-                                            id="vmap_select_snap_avoid_intersections_1_{{$index}}"
-                                            ng-model="ctrl.tmpSnapOptions.avoidIntersections[bo.bo_id]"
+                                            name="vmap_select_snap_avoid_superpositions_{{$index}}"
+                                            id="vmap_select_snap_avoid_superpositions_1_{{$index}}"
+                                            ng-model="ctrl.tmpSnapOptions.avoidSuperpositions[bo.bo_id]"
                                             ng-value="true">
-                                    <label for="vmap_select_snap_avoid_intersections_1_{{$index}}">Oui</label>
+                                    <label for="vmap_select_snap_avoid_superpositions_1_{{$index}}">Oui</label>
                                 </div>
                                 <div class="radio radio-inline">
                                     <input  type="radio"
-                                            name="vmap_select_snap_avoid_intersections_{{$index}}"
-                                            id="vmap_select_snap_avoid_intersections_2_{{$index}}"
-                                            ng-model="ctrl.tmpSnapOptions.avoidIntersections[bo.bo_id]"
+                                            name="vmap_select_snap_avoid_superpositions_{{$index}}"
+                                            id="vmap_select_snap_avoid_superpositions_2_{{$index}}"
+                                            ng-model="ctrl.tmpSnapOptions.avoidSuperpositions[bo.bo_id]"
                                             ng-value="false">
-                                    <label for="vmap_select_snap_avoid_intersections_2_{{$index}}">Non</label>
+                                    <label for="vmap_select_snap_avoid_superpositions_2_{{$index}}">Non</label>
                                 </div>
                             </div>
                         </div>
diff --git a/module/javascript/app/vmap/tools/insert.js b/module/javascript/app/vmap/tools/insert.js
index eededf5467b5420a32c15347b12dcea5c48b63bb..c9b7ddb3b96dad23da9e4b647c3edf0f6437b836 100644
--- a/module/javascript/app/vmap/tools/insert.js
+++ b/module/javascript/app/vmap/tools/insert.js
@@ -187,7 +187,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController = function ($scope,
         this['snapOptions']['mode'] = oVmap['properties']['snapping']['defaut_snapp_mode'];
         this['snapOptions']['limit'] = oVmap['properties']['snapping']['defaut_limit'];
         this['snapOptions']['visible'] = oVmap['properties']['snapping']['defaut_visibility'];
-        this['snapOptions']['avoidIntersections'] = {};
+        this['snapOptions']['avoidSuperpositions'] = {};
     }
 
     /**
@@ -259,9 +259,9 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController = function ($scope,
     $scope['aQueryableBOs'] = oVmap.getMapManager().getQueryableBusinessObjectsAsArray(true);
 
     /**
      * Business objects avaliable for avoiding intersections
      */
-    $scope['aAvoidIntersectionsBOs'] = [];
+    $scope['aAvoidSuperpositionsBOs'] = [];
 
     /**
      * Object to insert
@@ -374,7 +374,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController = function ($scope,
     this.$scope_.$watch('selectedBoId', function () {
         this_.updateInsertForm(null, function(){
             this_.selectCurrentBoForSnapping();
-            this_.loadAvoidIntersectionBos();
+            this_.loadAvoidSuperpositionBos();
         });
     });
 
@@ -419,7 +419,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.loadInsert
     });
 
     this.checkEditionScale();
-    this.loadAvoidIntersectionBos();
+    this.loadAvoidSuperpositionBos();
 };
 
 /**
@@ -444,11 +444,11 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.selectCurr
 
 
 /**
- * Load this.aAvoidIntersectionsBOs
+ * Load this.aAvoidSuperpositionsBOs
  *
  */
-nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.loadAvoidIntersectionBos = function () {
-    oVmap.log('nsVmap.nsToolsManager.Insert.inserttoolController.loadAvoidIntersectionBos');
+nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.loadAvoidSuperpositionBos = function () {
+    oVmap.log('nsVmap.nsToolsManager.Insert.inserttoolController.loadAvoidSuperpositionBos');
 
     var this_ = this;
 
@@ -456,7 +456,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.loadAvoidI
     var aActiveGeomTypes = ['POLYGON', 'MULTIPOLYGON', 'GEOMETRY', 'GEOMETRYCOLLECTION'];
 
     // Objets métiers actifs pour la calcul des jointures
-    this.$scope_['aAvoidIntersectionsBOs'] = [];
+    this.$scope_['aAvoidSuperpositionsBOs'] = [];
 
     if (goog.isDefAndNotNull(this.$scope_['oInsertObject']['sGeomType'])) {
 
@@ -468,7 +468,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.loadAvoidI
                 if (goog.isDefAndNotNull(this_.$scope_['aQueryableBOs'][i]['bo_geom_type'])) {
                     if(aActiveGeomTypes.indexOf(this_.$scope_['aQueryableBOs'][i]['bo_geom_type']) !== -1){
 
-                        this.$scope_['aAvoidIntersectionsBOs'].push(this_.$scope_['aQueryableBOs'][i]);
+                        this.$scope_['aAvoidSuperpositionsBOs'].push(this_.$scope_['aQueryableBOs'][i]);
                     }
                 }
             }
@@ -1114,8 +1114,8 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.startDrawi
                 var feature = evt.feature;
                 // Si la géométrie est un cercle, alors elle est remplacée par un polygone à 32 côtés
                 feature = this_.updateCircleGeoms(feature);
-                // Évite les intersections avec les autres couches si besoin
-                this_.avoidIntersections(feature);
+                // Évite les superpositions avec les autres couches si besoin
+                this_.avoidSuperpositions(feature);
             }, this);
 
 
@@ -1187,38 +1187,38 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.updateCirc
 };
 
 /**
  * Edit the given feature to avoid intersections with layers defined in snapOptions.avoidIntersections
  * @param {ol.Feature} olFeature
  * @returns {ol.Feature}
  */
-nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.avoidIntersections = function (olFeature) {
-    oVmap.log('nsVmap.nsToolsManager.Insert.inserttoolController.avoidIntersections');
+nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.avoidSuperpositions = function (olFeature) {
+    oVmap.log('nsVmap.nsToolsManager.Insert.inserttoolController.avoidSuperpositions');
 
     // Objets métiers à intersecter
-    var aIntersectionBos = [];
-    for (var bo_id in this['snapOptions']['avoidIntersections']) {
-        if (this['snapOptions']['avoidIntersections'][bo_id] === true) {
-            aIntersectionBos.push(bo_id);
+    var aSuperpositionBos = [];
+    for (var bo_id in this['snapOptions']['avoidSuperpositions']) {
+        if (this['snapOptions']['avoidSuperpositions'][bo_id] === true) {
+            aSuperpositionBos.push(bo_id);
         }
     }
 
     // Remplace la géométrie par celle calculée
-    if (aIntersectionBos.length > 0) {
-        this.setDiffGeom_(aIntersectionBos, olFeature)
+    if (aSuperpositionBos.length > 0) {
+        this.setDiffGeom_(aSuperpositionBos, olFeature)
     }
 }
 
 /**
  * Modify the feature geometry to avoid intersections with BOs in aIntersectionBos
  *
- * @param  {string} aIntersectionBos
+ * @param  {string} aSuperpositionBos
  * @param  {ol.Feature} olFeature
  * @param  {object|undefines} opt_options
  */
-nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.setDiffGeom_ = function (aIntersectionBos, olFeature, opt_options) {
+nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.setDiffGeom_ = function (aSuperpositionBos, olFeature, opt_options) {
     oVmap.log('nsVmap.nsToolsManager.Insert.inserttoolController.setDiffGeom_');
 
-    if (!goog.isArray(aIntersectionBos)) {
+    if (!goog.isArray(aSuperpositionBos)) {
         return 0;
     }
     if (!goog.isDefAndNotNull(olFeature)) {
@@ -1233,15 +1233,15 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.setDiffGeo
     var this_ = this;
     var sEWKTGeom = oVmap.getEWKTFromGeom(olFeature.getGeometry());
 
-    this.getDiffGeom_(aIntersectionBos[opt_options.bo_index], sEWKTGeom).then(function(sNewEWKTGeom){
+    this.getDiffGeom_(aSuperpositionBos[opt_options.bo_index], sEWKTGeom).then(function(sNewEWKTGeom){
 
         // Remplace la géométrie
         olFeature.setGeometry(oVmap.getGeomFromEWKT(sNewEWKTGeom));
 
         // Relance la fonction pour les autres objets métiers
         opt_options.bo_index ++;
-        if (opt_options.bo_index < aIntersectionBos.length) {
-            this_.setDiffGeom_(aIntersectionBos, olFeature, opt_options);
+        if (opt_options.bo_index < aSuperpositionBos.length) {
+            this_.setDiffGeom_(aSuperpositionBos, olFeature, opt_options);
         }
     }, function(err){
         console.log('Cannot get the diff geom: ', err)
@@ -1250,7 +1250,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.setDiffGeo
 }
 
 /**
  * Get the diff intersection geometry
  *
  * @param  {string} sBoId
  * @param  {string} sEWKTGeom
@@ -1640,8 +1640,8 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.showSnappi
 
     this.$scope_.$applyAsync(function(){
         for (var i = 0; i < this_.$scope_['aQueryableBOs'].length; i++) {
-            if (!goog.isDefAndNotNull(this_['tmpSnapOptions']['avoidIntersections'][this_.$scope_['aQueryableBOs'][i]['bo_id']])) {
-                this_['tmpSnapOptions']['avoidIntersections'][this_.$scope_['aQueryableBOs'][i]['bo_id']] = false;
+            if (!goog.isDefAndNotNull(this_['tmpSnapOptions']['avoidSuperpositions'][this_.$scope_['aQueryableBOs'][i]['bo_id']])) {
+                this_['tmpSnapOptions']['avoidSuperpositions'][this_.$scope_['aQueryableBOs'][i]['bo_id']] = false;
             }
         }
     });
@@ -259,9 +259,9 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController = function ($scope,
 
     /**
-     * Business objects avaliable for avoiding intersections
+     * Business objects avaliable for avoiding superpositions
      */
@@ -1187,38 +1187,38 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.updateCirc
 
 /**
- * Edit the given feature to avoid intersections with layers defined in snapOptions.avoidIntersections
+ * Edit the given feature to avoid superpositions with layers defined in snapOptions.avoidSuperpositions
  * @param {ol.Feature} olFeature
  * @returns {ol.Feature}
@@ -1187,38 +1187,38 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.updateCirc
 
 /**
- * Modify the feature geometry to avoid intersections with BOs in aIntersectionBos
+ * Modify the feature geometry to avoid superpositions with BOs in aSuperpositionBos
  *
@@ -1250,7 +1250,7 @@ nsVmap.nsToolsManager.Insert.prototype.inserttoolController.prototype.setDiffGeo
 
 /**
- * Get the diff intersection geometry
+ * Get the diff superposition geometry
  *
  * @param  {string} sBoId
diff --git a/module/javascript/app/vmap/tools/select/select.js b/module/javascript/app/vmap/tools/select/select.js
index 64f0ec6defefc3aaa54c1d48e60eaac4c4036bd8..9ade4f6c1eb3ea02054a870c64c2fb7c295de894 100755
--- a/module/javascript/app/vmap/tools/select/select.js
+++ b/module/javascript/app/vmap/tools/select/select.js
@@ -366,7 +366,7 @@ nsVmap.nsToolsManager.Select.prototype.selectController = function ($scope, $tim
         this['snapOptions']['mode'] = oVmap['properties']['snapping']['defaut_snapp_mode'];
         this['snapOptions']['limit'] = oVmap['properties']['snapping']['defaut_limit'];
         this['snapOptions']['visible'] = oVmap['properties']['snapping']['defaut_visibility'];
-        this['snapOptions']['avoidIntersections'] = {};
+        this['snapOptions']['avoidSuperpositions'] = {};
     }
 
     /**
@@ -380,9 +380,9 @@ nsVmap.nsToolsManager.Select.prototype.selectController = function ($scope, $tim
     this['aQueryableBOs'] = [];
 
     /**
     * Business objects avaliable for avoiding intersections
     */
-    $scope['aAvoidIntersectionsBOs'] = [];
+    $scope['aAvoidSuperpositionsBOs'] = [];
 
     /**
      * Tree resulting the various GetFeatureInfo requests
@@ -542,9 +542,9 @@ nsVmap.nsToolsManager.Select.prototype.selectController = function ($scope, $tim
         console.log("evt: ", evt);
         console.log("aFeatures: ", aFeatures);
 
         // Évite les intersections avec les autres couches si besoin
         for (var i = 0; i < aFeatures.length; i++) {
-            this_.avoidIntersections(aFeatures[i]).then(function(){
+            this_.avoidSuperpositions(aFeatures[i]).then(function(){
                 console.log('2');
             });
         }
@@ -711,11 +711,11 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.loadQueryableB
 };
 
 /**
- * Load this.aAvoidIntersectionsBOs
+ * Load this.aAvoidSuperpositionsBOs
  *
  */
-nsVmap.nsToolsManager.Select.prototype.selectController.prototype.loadAvoidIntersectionBos = function () {
-    oVmap.log('nsVmap.nsToolsManager.Select.selectController.loadAvoidIntersectionBos');
+nsVmap.nsToolsManager.Select.prototype.selectController.prototype.loadAvoidSuperpositionBos = function () {
+    oVmap.log('nsVmap.nsToolsManager.Select.selectController.loadAvoidSuperpositionBos');
 
     var this_ = this;
 
@@ -723,7 +723,7 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.loadAvoidInter
     var aActiveGeomTypes = ['POLYGON', 'MULTIPOLYGON', 'GEOMETRY', 'GEOMETRYCOLLECTION'];
 
     // Objets métiers actifs pour la calcul des jointures
-    this.$scope_['aAvoidIntersectionsBOs'] = [];
+    this.$scope_['aAvoidSuperpositionsBOs'] = [];
 
     console.log("this['editableFeatureType']: ", this['editableFeatureType']);
     console.log("this['aQueryableBOs']: ", this['aQueryableBOs']);
@@ -738,14 +738,14 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.loadAvoidInter
                 if (goog.isDefAndNotNull(this['aQueryableBOs'][i]['bo_geom_type'])) {
                     if(aActiveGeomTypes.indexOf(this['aQueryableBOs'][i]['bo_geom_type']) !== -1){
 
-                        this.$scope_['aAvoidIntersectionsBOs'].push(this['aQueryableBOs'][i]);
+                        this.$scope_['aAvoidSuperpositionsBOs'].push(this['aQueryableBOs'][i]);
                     }
                 }
             }
         }
     }
 
-    console.log("this.$scope_['aAvoidIntersectionsBOs']: ", this.$scope_['aAvoidIntersectionsBOs']);
+    console.log("this.$scope_['aAvoidSuperpositionsBOs']: ", this.$scope_['aAvoidSuperpositionsBOs']);
 }
 
 /**
@@ -1944,7 +1944,7 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.editFeature =
         $('#basictools-select-modify-palette').show();
 
         // Chage le liste des BO intersectables par calcul de polygones jointifs
-        this_.loadAvoidIntersectionBos();
+        this_.loadAvoidSuperpositionBos();
 
         // Timeout car lors du toggleOutTools, clearOverlays est lancé
         setTimeout(function () {
@@ -2192,8 +2192,8 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.startDrawing =
                 this_.oOverlayLayer_.getSource().addFeature(feature);
             }
 
-            // Évite les intersections avec les autres couches si besoin
-            this_.avoidIntersections(feature);
+            // Évite les superpositions avec les autres couches si besoin
+            this_.avoidSuperpositions(feature);
 
             // Ajoute les géométries en mode multi ou simple à editableSelection.olFeature
             this_.putFeaturesOnTheElement(this_.oOverlayFeatures_.getArray());
@@ -2202,26 +2202,26 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.startDrawing =
 };
 
 /**
  * Edit the given feature to avoid intersections with layers defined in snapOptions.avoidIntersections
  * @param {ol.Feature} olFeature
  * @returns {ol.Feature}
  */
-nsVmap.nsToolsManager.Select.prototype.selectController.prototype.avoidIntersections = function (olFeature) {
-    oVmap.log('nsVmap.nsToolsManager.Select.selectController.avoidIntersections');
+nsVmap.nsToolsManager.Select.prototype.selectController.prototype.avoidSuperpositions = function (olFeature) {
+    oVmap.log('nsVmap.nsToolsManager.Select.selectController.avoidSuperpositions');
 
     var deferred = this.$q_.defer();
 
     // Objets métiers à intersecter
-    var aIntersectionBos = [];
-    for (var bo_id in this['snapOptions']['avoidIntersections']) {
-        if (this['snapOptions']['avoidIntersections'][bo_id] === true) {
-            aIntersectionBos.push(bo_id);
+    var aSuperpositionBos = [];
+    for (var bo_id in this['snapOptions']['avoidSuperpositions']) {
+        if (this['snapOptions']['avoidSuperpositions'][bo_id] === true) {
+            aSuperpositionBos.push(bo_id);
         }
     }
 
     // Remplace la géométrie par celle calculée
-    if (aIntersectionBos.length > 0) {
-        this.setDiffGeom_(aIntersectionBos, olFeature).then(function(olFeature){
+    if (aSuperpositionBos.length > 0) {
+        this.setDiffGeom_(aSuperpositionBos, olFeature).then(function(olFeature){
             console.log('1');
 
             deferred.resolve(olFeature);
@@ -2232,16 +2232,16 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.avoidIntersect
 }
 
 /**
  * Modify the feature geometry to avoid intersections with BOs in aIntersectionBos
  *
- * @param  {string} aIntersectionBos
+ * @param  {string} aSuperpositionBos
  * @param  {ol.Feature} olFeature
  * @param  {object|undefines} opt_options
  */
-nsVmap.nsToolsManager.Select.prototype.selectController.prototype.setDiffGeom_ = function (aIntersectionBos, olFeature, opt_options) {
+nsVmap.nsToolsManager.Select.prototype.selectController.prototype.setDiffGeom_ = function (aSuperpositionBos, olFeature, opt_options) {
     oVmap.log('nsVmap.nsToolsManager.Select.selectController.setDiffGeom_');
 
-    if (!goog.isArray(aIntersectionBos)) {
+    if (!goog.isArray(aSuperpositionBos)) {
         return 0;
     }
     if (!goog.isDefAndNotNull(olFeature)) {
@@ -2257,15 +2257,15 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.setDiffGeom_ =
     var deferred = this.$q_.defer();
     var sEWKTGeom = oVmap.getEWKTFromGeom(olFeature.getGeometry());
 
-    this.getDiffGeom_(aIntersectionBos[opt_options.bo_index], sEWKTGeom).then(function(sNewEWKTGeom){
+    this.getDiffGeom_(aSuperpositionBos[opt_options.bo_index], sEWKTGeom).then(function(sNewEWKTGeom){
 
         // Remplace la géométrie
         olFeature.setGeometry(oVmap.getGeomFromEWKT(sNewEWKTGeom));
 
         // Relance la fonction pour les autres objets métiers
         opt_options.bo_index ++;
-        if (opt_options.bo_index < aIntersectionBos.length) {
-            this_.setDiffGeom_(aIntersectionBos, olFeature, opt_options).then(function(){
+        if (opt_options.bo_index < aSuperpositionBos.length) {
+            this_.setDiffGeom_(aSuperpositionBos, olFeature, opt_options).then(function(){
                 deferred.resolve(olFeature);
             });
         } else {
@@ -2279,7 +2279,7 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.setDiffGeom_ =
 }
 
 /**
  * Get the diff intersection geometry
  *
  * @param  {string} sBoId
  * @param  {string} sEWKTGeom
@@ -2582,8 +2582,8 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.showSnappingOp
 
     this.$scope_.$applyAsync(function(){
         for (var i = 0; i < this_['aQueryableBOs'].length; i++) {
-            if (!goog.isDefAndNotNull(this_['tmpSnapOptions']['avoidIntersections'][this_['aQueryableBOs'][i]['bo_id']])) {
-                this_['tmpSnapOptions']['avoidIntersections'][this_['aQueryableBOs'][i]['bo_id']] = false;
+            if (!goog.isDefAndNotNull(this_['tmpSnapOptions']['avoidSuperpositions'][this_['aQueryableBOs'][i]['bo_id']])) {
+                this_['tmpSnapOptions']['avoidSuperpositions'][this_['aQueryableBOs'][i]['bo_id']] = false;
             }
         }
     });
@@ -380,9 +380,9 @@ nsVmap.nsToolsManager.Select.prototype.selectController = function ($scope, $tim
 
     /**
-    * Business objects avaliable for avoiding intersections
+    * Business objects avaliable for avoiding superpositions
     */
@@ -542,9 +542,9 @@ nsVmap.nsToolsManager.Select.prototype.selectController = function ($scope, $tim
         console.log("aFeatures: ", aFeatures);
 
-        // Évite les intersections avec les autres couches si besoin
+        // Évite les superpositions avec les autres couches si besoin
         for (var i = 0; i < aFeatures.length; i++) {
@@ -2202,26 +2202,26 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.startDrawing =
 
 /**
- * Edit the given feature to avoid intersections with layers defined in snapOptions.avoidIntersections
+ * Edit the given feature to avoid superpositions with layers defined in snapOptions.avoidSuperpositions
  * @param {ol.Feature} olFeature
  * @returns {ol.Feature}
@@ -2232,16 +2232,16 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.avoidIntersect
 
 /**
- * Modify the feature geometry to avoid intersections with BOs in aIntersectionBos
+ * Modify the feature geometry to avoid superpositions with BOs in aSuperpositionBos
  *
@@ -2279,7 +2279,7 @@ nsVmap.nsToolsManager.Select.prototype.selectController.prototype.setDiffGeom_ =
 
 /**
- * Get the diff intersection geometry
+ * Get the diff superposition geometry
  *
  * @param  {string} sBoId